@@ -12,7 +12,7 @@ use Text::VisualWidth::PP;
 $Text::VisualWidth::PP::EastAsian = 1;
 use parent qw/ Exporter /;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 our @EXPORT    = qw/ format_cols print_cols pretty_print_cols /;
 our @EXPORT_OK = qw/ _max _min _validate _align /;
@@ -142,11 +142,7 @@ Array::PrintCols::EastAsian - Print or format space-fill array elements with ali
 
 =head1 VERSION
 
-<<<<<<< HEAD
-This document describes Array::PrintCols::EastAsian version 0.04.
-=======
-This document describes Array::PrintCols::EastAsian version 0.02.
->>>>>>> develop
+This document describes Array::PrintCols::EastAsian version 0.05.
 
 =head1 SYNOPSIS
 
